.. mols2grid documentation master file, created by
   sphinx-quickstart on Fri Apr  1 19:31:58 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mols2grid's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents

   contents

.. toctree::
   :maxdepth: 3
   :caption: Notebooks

   notebooks/quickstart
   notebooks/customization
   notebooks/filtering
   notebooks/callbacks

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   api/simple
   api/molgrid
   api/callbacks
   api/utils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
